@@ -7,7 +7,7 @@ Autor: zmf96
 Email: zmf96@qq.com
 Date: 2022-02-21 08:46:14
 LastEditors: zmf96
-LastEditTime: 2022-02-21 10:13:27
+LastEditTime: 2022-02-22 03:48:54
 FilePath: /subdomain/subdomain.py
 Description: 
 '''
@@ -19,15 +19,19 @@ import aiodns
 import argparse
 import IPy
 import random
+import logging
+
+__version__ = '0.1.2'
 
 BASEDIR = os.path.dirname(os.path.abspath(__file__))
 
+
 class SubDomain:
     def __init__(self, paras={}):
         self.basedir = os.path.dirname(os.path.abspath(__file__))
         self.deep = paras['deep']
         self.check_analysis = True  # 通过cname 判断泛解析 这个方法极度损耗性能相当于查询两遍dns
-        self.analysis_domain =  []
+        self.analysis_domain = []
         self.queue = asyncio.Queue(maxsize=3000000)
         self.check_bk = paras['check_bk'] if paras.get('check_bk') else True
         self.black_list = {}  # 黑名单ip  黑明单键值为10
@@ -43,11 +47,12 @@ class SubDomain:
         self.domain = paras.get('domain')
         self.dictname = paras['dictname']
         self.sec_dictname = "test.txt"  # "subdict.txt"  # 递归小字典
-        self.semaphore = asyncio.Semaphore(10000)  # 协程并发量  4m带宽
+        self.semaphore = asyncio.Semaphore(100000)  # 协程并发量  40m带宽
         self.subdomain_list = set()
         self.deep_domain = []
         self.scan_total = 0
         self.find_total = 0
+        self.results = {}
 
     def init_bk(self):
         '''
@@ -113,31 +118,34 @@ class SubDomain:
         try:
             while True:
                 size = self.queue.qsize()
-                # if size <= 1000000:
-                #     if self.deep_domain:
-                #         sub_text = self.deep_domain[0]
-                #         self.deep_domain.remove(sub_text)
-                #         with open(os.path.join(BASEDIR,'dict/' + self.sec_dictname,), 'r') as f:
-                #             for line in f:
-                #                 self.queue.put_nowait(
-                #                     line.strip().lower() + "." + sub_text)
+                if size <= 1000000:
+                    if self.deep_domain:
+                        sub_text = self.deep_domain[0]
+                        self.deep_domain.remove(sub_text)
+                        with open(os.path.join(BASEDIR, 'dict/' + self.sec_dictname,), 'r') as f:
+                            for line in f:
+                                self.queue.put_nowait(
+                                    line.strip().lower() + "." + sub_text)
                 sub = await self.queue.get()
                 self.scan_total += 1
-                logger.debug("remain " + str(self.scan_total) + "  | Found" +
-                            str(self.find_total) + '\r')
+                # logger.debug("remain " + str(self.scan_total) + "  | Found" +
+                #             str(self.find_total) + '\r')
                 if self.check_analysis:
                     cname = await self.query(sub, self.semaphore, "CNAME")
                     if cname:
                         cname = cname.cname
                         if cname in self.analysis_domain:
-                             continue
+                            continue
                 res = await self.query(sub, self.semaphore, "A")
                 if res:
                     subdomain = sub+"."+self.domain
                     sub_ips = [r.host for r in res]
                     if self.is_black(sub_ips):
                         self.find_total += 1
-                        logger.info(f'{subdomain} {sub_ips}')
+                        # logger.info(f'{subdomain} {sub_ips}')
+                        self.results[subdomain] = sub_ips
+                        logger.debug("remain " + str(self.scan_total) + "  | Found " +
+                                     str(self.find_total) + ' subdomain:' + subdomain)
                         # self.save_and_next(subdomain, sub_ips)
                 self.queue.task_done()
         except Exception as e:
@@ -147,12 +155,12 @@ class SubDomain:
         '''
         开始爆破
         '''
-        with open(os.path.join(BASEDIR,'dict/'+self.dictname), 'r') as f:
+        with open(os.path.join(BASEDIR, 'dict/'+self.dictname), 'r') as f:
             for line in f:
                 domain = line.strip().lower()
                 self.queue.put_nowait(domain)
         brute_tasks = [self.loop.create_task(
-            self.brute_domain()) for _ in range(10000)] # 启动10000个协程
+            self.brute_domain()) for _ in range(40000)]  # 启动10000个协程
         await self.queue.join()
         for task in brute_tasks:
             task.cancel()
@@ -181,13 +189,13 @@ class SubDomain:
 def main():
     logger.debug("subdomain  version 0.1")
     parser = argparse.ArgumentParser(description='使用aiodns爆破子域名')
-    parser.add_argument("-v", "--version", action='version', version=' 0.1.0')
+    parser.add_argument("-v", "--version",
+                        action='version', version=__version__)
     parser.add_argument("-f", "--file", type=str,
                         help='指定字典文件', default='default.txt')
     parser.add_argument("-d", "--domain", type=str,
-                        help='目标域名', default='jd.com')
-    parser.add_argument("-s", "--deep", type=int, help='域名深度,默认 2', default=3)
-
+                        help='目标域名', required=True)
+    parser.add_argument("-s", "--deep", type=int, help='域名深度,默认 1', default=1)
     args = parser.parse_args()
     params = {}
     if args.domain is None:
@@ -199,6 +207,7 @@ def main():
     params['dictname'] = args.file
     sd = SubDomain(paras=params)
     sd.run()
+    print(sd.results)
 
 
 if __name__ == '__main__':
